class PFXError(Exception):
    """Base class for all PandaFlex exceptions"""
    pass

class PFXParseError(PFXError):
    """Raised when there's an error parsing a PFX file"""
    pass

class PFXValidationError(PFXError):
    """Raised when a PFX file fails validation"""
    pass

class PFXSchemaError(PFXError):
    """Raised when there's a schema mismatch"""
    pass