from setuptools import setup, find_packages
from pathlib import Path

# Read the contents of README file
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text(encoding="utf-8")

setup(
    name="pandaflex",
    version="1.0.0",
    description="PandaFlex (PFX) - A new efficient data format for pandas",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Louati Mahdi",
    author_email="louatimahdi390@gmail.com",
    url="https://github.com/mahdi123-tech",
    packages=find_packages(),
    install_requires=[
        "pandas>=1.0.0",
        "numpy>=1.18.0",
    ],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Scientific/Engineering",
        "Topic :: Software Development",
    ],
    python_requires=">=3.7",
    entry_points={
        'console_scripts': [
            'pandaflex=pandaflex.cli:main',
        ],
    },
    include_package_data=True,
    package_data={
        'pandaflex': ['examples/*.pfx'],
    },
)