from .version import __version__
from .reader import read_pfx
from .writer import to_pfx
from .utils import generate_example, validate_pfx
import os
from .utils import generate_example

# Generate example file on first import
if not os.path.exists('example.pfx'):
    generate_example()
    print("Generated example.pfx in your current directory. Check README.md for usage instructions.")

__all__ = ['read_pfx', 'to_pfx', 'generate_example', 'validate_pfx', '__version__']